/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */



// load templates here

require('templates/main/service/info/summary/base');
require('templates/common/progress');
require('templates/main/alerts/alert_instance/status');
require("templates/main/service/widgets/create/step2_number");
require("templates/main/service/widgets/create/step2_template");
require("templates/main/service/widgets/create/step2_graph");
require('templates/common/configs/widgets/controls');
require('templates/common/configs/widgets/controls/create_override');
require('templates/common/configs/widgets/controls/remove_override');
require('templates/common/configs/widgets/controls/final');
require('templates/common/configs/widgets/controls/set_recommended');
require('templates/common/configs/widgets/controls/undo');
require('templates/common/configs/widgets/controls/edit');
require('templates/common/configs/widgets/config_label');
require('templates/common/configs/configs_comparison_row');
require('templates/common/configs/configs_comparison_cell');
require('templates/wizard/installer_cancel_button');
